import React from 'react';
import { ReactWidget } from '@jupyterlab/apputils';
import { Widget } from '@lumino/widgets';
import { DagDataView } from './dataview';
import { tableContent } from './api/datamanage';

class DataTableWidget extends ReactWidget {
  constructor(table: any, options?: Widget.IOptions) {
    super(options);
    void this._requestData(table, 1, 100);
    this._table = table;
  }

  private _requestData = async (table: any, page: number, size: number) => {
    console.log(table);
    const res = await tableContent({
      table_name: table.table_name,
      page,
      size
    });
    if (res === 'error') {
      this._err = res;
    } else {
      const { content, header, total } = res;
      this._data = { fields: header, dataList: content, total };
    }
    this.update();
  };

  render(): JSX.Element {
    if (this._err) {
      return <div>Error</div>;
    } else if (!this._data) {
      return <div>Loading ...</div>;
    } else {
      return (
        <DagDataView
          data={this._data}
          info={this._table}
          changePage={(page, size) =>
            this._requestData(this._table, page, size)
          }
        />
      );
    }
  }

  private _data: any | null = null;
  private _err: any;
  private _table: any;
}

export default DataTableWidget;
