import React from 'react';
// import { PlusCircleOutlined } from '@ant-design/icons';
import { Form, Input, Space, Select, message, Checkbox, Radio } from 'antd';
import { getDebugTable, getLocalDebugTable, getSchema } from './request';

export default class DatasourceNodeInfo extends React.Component<any, any> {
  formRef = React.createRef();

  constructor(props: any) {
    super(props);
    this.state = {
      debugTable: [],
      localDebugTable: [],
      inputFields: [],
      currentTablePath: 'node'
    };
  }

  async getDebugTableList() {
    const { data } = await getDebugTable({
      user_id: 'test',
      project_id: 'test'
    });
    if (data.code === 200) {
      this.setState({ debugTable: data.data });
    } else {
      message.error('获取调试数据表失败');
    }
  }
  async getLocalDebugTableList() {
    const { data } = await getLocalDebugTable();
    if (data.code === 200) {
      this.setState({ localDebugTable: data.data });
    } else {
      message.error('获取本地调试数据表失败');
    }
  }

  async getTableSchema(table_name: string) {
    console.log(table_name);
    const { data } = await getSchema(table_name);
    if (data.code === 200) {
      const input = data.data.map((item: any) => {
        const strs = item.split(':');
        return {
          dataSelect: false,
          dataField: strs[1],
          dataType: strs[2]
        };
      });
      this.props.nodeInfo.inputSource = input;
    } else {
      message.error('获取本地调试数据表失败');
    }
  }

  componentDidMount() {
    this.setState({ currentTablePath: this.props.nodeInfo.tablePath });
    this.getDebugTableList();
    this.getLocalDebugTableList();
  }

  render() {
    return (
      <div className="node-datasource">
        <Form
          ref={this.formRef as any}
          name="datasourceInfo"
          autoComplete="off"
          layout="vertical"
          initialValues={{
            inputDatasource: this.props.nodeInfo.inputSource,
            dataTable: this.props.nodeInfo.dataTableId,
            nodeName: this.props.nodeInfo.nodeName,
            tablePath: this.props.nodeInfo.tablePath
          }}
        >
          <Form.Item name="nodeName" label="节点名称:">
            <Input
              placeholder="请输入节点名称"
              onChange={e => {
                this.props.nodeInfo.nodeName = e.target.value;
              }}
            />
          </Form.Item>
          <Form.Item name="tablePath" label="选择调试表路径:">
            <Radio.Group
              onChange={e => {
                this.props.nodeInfo.tablePath = e.target.value;
                this.setState({ currentTablePath: e.target.value });
              }}
            >
              <Radio value="node">本地数据</Radio>
              <Radio value="local">系统数据</Radio>
            </Radio.Group>
          </Form.Item>
          <p>添加调试数据表:</p>
          <Form.Item
            name="dataTable"
            style={{ width: '80%', marginTop: '5px' }}
          >
            <Select
              options={
                this.state.currentTablePath === 'node'
                  ? this.state.debugTable.map((item: any) => {
                      return { label: item.name, value: item.table_name };
                    })
                  : this.state.localDebugTable.map((item: any) => {
                      return { label: item, value: item };
                    })
              }
              placeholder="选择调试数据表"
              onSelect={(val: any, option: any) => {
                this.props.nodeInfo.dataTableId = val;
                this.props.nodeInfo.dataTableName = option.label;
                this.getTableSchema(val);
                (this.formRef.current as any).setFieldsValue({
                  inputDatasource: this.props.nodeInfo.inputSource
                });
              }}
            />
          </Form.Item>
          <p>输入源:</p>
          <Form.List name="inputDatasource">
            {(fields, { add, remove }) => (
              <>
                {fields.map(({ key, name, ...restField }) => (
                  <Space
                    key={key}
                    style={{ display: 'flex', margin: '10px 0 -20px' }}
                    align="baseline"
                  >
                    <Form.Item
                      {...restField}
                      name={[name, 'dataSelect']}
                      valuePropName="checked"
                    >
                      <Checkbox
                        onChange={e => {
                          this.props.nodeInfo.inputSource = (this.formRef
                            .current as any).getFieldsValue().inputDatasource;
                        }}
                      />
                    </Form.Item>
                    <Form.Item
                      {...restField}
                      name={[name, 'dataField']}
                      rules={[{ required: true, message: '请填写字段' }]}
                    >
                      <Input placeholder="字段名" disabled />
                    </Form.Item>
                    <Form.Item
                      {...restField}
                      name={[name, 'dataType']}
                      rules={[{ required: true, message: '请填写字段类型' }]}
                    >
                      <Select
                        options={[
                          { label: 'string', value: 'string' },
                          { label: 'int', value: 'int' },
                          { label: 'text', value: 'text' },
                          { label: 'float', value: 'float' },
                          { label: 'double', value: 'double' }
                        ]}
                        placeholder="请选择字段类型"
                        disabled
                      />
                    </Form.Item>
                  </Space>
                ))}
                {/* <Form.Item>
                  <Button type="link" onClick={() => {
                    add()
                  }} icon={<PlusCircleOutlined />} style={{paddingLeft: 0, paddingRight: 0}}>
                    添加字段
                  </Button>
                </Form.Item> */}
              </>
            )}
          </Form.List>
        </Form>
      </div>
    );
  }
}
