import React from 'react';
import { PlusCircleOutlined, MinusCircleOutlined } from '@ant-design/icons';
import { Form, Input, Space, Select, Button } from 'antd';

export default class OutputNodeInfo extends React.Component<any, any> {
  formRef = React.createRef();

  constructor(props: any) {
    super(props);
    this.state = {
      outputFieldEditing: false,
      outputTypeEditing: false
    };
  }

  componentDidMount() {
    (this.formRef.current as any).setFieldsValue({
      outputSource: this.props.nodeInfo.outputSource
    });
  }

  enterOutputField(e: any, index: number) {
    const outputSource = this.props.nodeInfo.outputSource;
    if (outputSource[index]) {
      outputSource[index]['dataField'] = e.target.value.trim();
    } else {
      outputSource.push({ dataField: e.target.value.trim() });
    }
  }

  changeOutputFieldType(val: string, index: number) {
    const outputSource = this.props.nodeInfo.outputSource;
    if (outputSource[index]) {
      outputSource[index]['dataType'] = val;
    } else {
      outputSource.push({ dataType: val });
    }
  }

  render() {
    return (
      <div className="node-datasource">
        <Form
          ref={this.formRef as any}
          name="datasourceInfo"
          autoComplete="off"
          layout="vertical"
          initialValues={{
            outputSource: this.props.nodeInfo.outputSource,
            nodeName: this.props.nodeInfo.nodeName
          }}
        >
          <Form.Item name="nodeName" label="节点名称:">
            <Input
              placeholder="请输入节点名称"
              onChange={e => {
                this.props.nodeInfo.nodeName = e.target.value;
              }}
            />
          </Form.Item>
          <p>输出:</p>
          <Form.List name="outputSource">
            {(fields, { add, remove }) => (
              <>
                {fields.map(({ key, name, ...restField }, index) => (
                  <Space
                    key={key}
                    style={{ display: 'flex', margin: '10px 0 -20px' }}
                    align="baseline"
                  >
                    <Form.Item
                      {...restField}
                      name={[name, 'dataField']}
                      rules={[{ required: true, message: '请填写字段' }]}
                    >
                      <Input
                        placeholder="字段名"
                        onChange={e => this.enterOutputField(e, index)}
                      />
                    </Form.Item>
                    <Form.Item
                      {...restField}
                      name={[name, 'dataType']}
                      rules={[{ required: true, message: '请填写字段类型' }]}
                    >
                      <Select
                        onChange={val => this.changeOutputFieldType(val, index)}
                        options={[
                          { label: 'string', value: 'string' },
                          { label: 'int', value: 'int' },
                          { label: 'text', value: 'text' },
                          { label: 'float', value: 'float' },
                          { label: 'double', value: 'double' }
                        ]}
                        placeholder="请选择字段类型"
                      />
                    </Form.Item>
                    {fields.length > 1 ? (
                      <MinusCircleOutlined
                        className="dynamic-delete-button"
                        onClick={() => remove(name)}
                        style={{ color: '#147BD1' }}
                      />
                    ) : null}
                  </Space>
                ))}
                <Form.Item>
                  <Button
                    type="link"
                    onClick={() => {
                      return add();
                    }}
                    icon={<PlusCircleOutlined />}
                    style={{ paddingLeft: 0, paddingRight: 0 }}
                  >
                    添加输出
                  </Button>
                </Form.Item>
              </>
            )}
          </Form.List>
        </Form>
      </div>
    );
  }
}
